@@ -633,7 +633,8 @@ theora_push_packet (GstTheoraEnc * enc, ogg_packet * packet)
     goto done;
   }
 
-  gst_buffer_fill (frame->output_buffer, 0, packet->packet, packet->bytes);
+  if (packet->bytes > 0)
+    gst_buffer_fill (frame->output_buffer, 0, packet->packet, packet->bytes);
 
   /* the second most significant bit of the first data byte is cleared
    * for keyframes */
@@ -786,22 +787,11 @@ theora_enc_write_multipass_cache (GstTheoraEnc * enc, gboolean begin,
   gsize bytes_written = 0;
   gchar *buf;
 
-  if (begin)
+  if (begin) {
     stat = g_io_channel_seek_position (enc->multipass_cache_fd, 0, G_SEEK_SET,
         &err);
-  if (stat != G_IO_STATUS_ERROR) {
-    do {
-      bytes_read =
-          th_encode_ctl (enc->encoder, TH_ENCCTL_2PASS_OUT, &buf, sizeof (buf));
-      if (bytes_read > 0)
-        g_io_channel_write_chars (enc->multipass_cache_fd, buf, bytes_read,
-            &bytes_written, NULL);
-    } while (bytes_read > 0 && bytes_written > 0);
 
-  }
-
-  if (stat == G_IO_STATUS_ERROR || bytes_read < 0) {
-    if (begin) {
+    if (stat == G_IO_STATUS_ERROR) {
       if (eos)
         GST_ELEMENT_WARNING (enc, RESOURCE, WRITE, (NULL),
             ("Failed to seek to beginning of multipass cache file: %s",
@@ -810,15 +800,34 @@ theora_enc_write_multipass_cache (GstTheoraEnc * enc, gboolean begin,
         GST_ELEMENT_ERROR (enc, RESOURCE, WRITE, (NULL),
             ("Failed to seek to beginning of multipass cache file: %s",
                 err->message));
+      g_error_free (err);
+      return FALSE;
+    }
+  }
+
+
+  do {
+    bytes_read =
+        th_encode_ctl (enc->encoder, TH_ENCCTL_2PASS_OUT, &buf, sizeof (buf));
+    if (bytes_read > 0)
+      g_io_channel_write_chars (enc->multipass_cache_fd, buf, bytes_read,
+          &bytes_written, &err);
+  } while (bytes_read > 0 && bytes_written > 0 && !err);
+
+  if (bytes_read < 0 || err) {
+    if (bytes_read < 0) {
+      GST_ELEMENT_ERROR (enc, RESOURCE, WRITE, (NULL),
+          ("Failed to read multipass cache data: %d", bytes_read));
     } else {
       GST_ELEMENT_ERROR (enc, RESOURCE, WRITE, (NULL),
-          ("Failed to write multipass cache file"));
+          ("Failed to write multipass cache file: %s", err->message));
     }
     if (err)
       g_error_free (err);
 
     return FALSE;
   }
+
   return TRUE;
 }
 
