@@ -14,21 +14,24 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 /**
  * SECTION:gstvideosink
- * @title: GstVideoSink
  * @short_description: Base class for video sinks
- *
- * Provides useful functions and a base class for video sinks.
- *
+ * 
+ * <refsect2>
+ * <para>
+ * Provides useful functions and a base class for video sinks. 
+ * </para>
+ * <para>
  * GstVideoSink will configure the default base sink to drop frames that
  * arrive later than 20ms as this is considered the default threshold for
  * observing out-of-sync frames.
- *
+ * </para>
+ * </refsect2>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -37,8 +40,6 @@
 
 #include "gstvideosink.h"
 
-G_DEFINE_TYPE (GstVideoSink, gst_video_sink, GST_TYPE_BASE_SINK);
-
 enum
 {
   PROP_SHOW_PREROLL_FRAME = 1
@@ -51,25 +52,8 @@ struct _GstVideoSinkPrivate
   gboolean show_preroll_frame;  /* ATOMIC */
 };
 
-#ifndef GST_DISABLE_GST_DEBUG
-#define GST_CAT_DEFAULT gst_video_sink_ensure_debug_category()
-
-static GstDebugCategory *
-gst_video_sink_ensure_debug_category (void)
-{
-  static gsize cat_gonce = 0;
-
-  if (g_once_init_enter (&cat_gonce)) {
-    GstDebugCategory *cat = NULL;
-
-    GST_DEBUG_CATEGORY_INIT (cat, "videosink", 0, "GstVideoSink");
-
-    g_once_init_leave (&cat_gonce, (gsize) cat);
-  }
-
-  return (GstDebugCategory *) cat_gonce;
-}
-#endif /* GST_DISABLE_GST_DEBUG */
+GST_DEBUG_CATEGORY_STATIC (video_sink_debug);
+#define GST_CAT_DEFAULT video_sink_debug
 
 static GstBaseSinkClass *parent_class = NULL;
 
@@ -89,7 +73,7 @@ static GstFlowReturn gst_video_sink_show_frame (GstBaseSink * bsink,
  * @dst: the #GstVideoRectangle describing the destination area
  * @result: a pointer to a #GstVideoRectangle which will receive the result area
  * @scaling: a #gboolean indicating if scaling should be applied or not
- *
+ * 
  * Takes @src rectangle and position it at the center of @dst rectangle with or
  * without @scaling. It handles clipping if the @src rectangle is bigger than
  * the @dst one and @scaling is set to FALSE.
@@ -103,8 +87,8 @@ gst_video_sink_center_rect (GstVideoRectangle src, GstVideoRectangle dst,
   if (!scaling) {
     result->w = MIN (src.w, dst.w);
     result->h = MIN (src.h, dst.h);
-    result->x = dst.x + (dst.w - result->w) / 2;
-    result->y = dst.y + (dst.h - result->h) / 2;
+    result->x = (dst.w - result->w) / 2;
+    result->y = (dst.h - result->h) / 2;
   } else {
     gdouble src_ratio, dst_ratio;
 
@@ -114,16 +98,16 @@ gst_video_sink_center_rect (GstVideoRectangle src, GstVideoRectangle dst,
     if (src_ratio > dst_ratio) {
       result->w = dst.w;
       result->h = dst.w / src_ratio;
-      result->x = dst.x;
-      result->y = dst.y + (dst.h - result->h) / 2;
+      result->x = 0;
+      result->y = (dst.h - result->h) / 2;
     } else if (src_ratio < dst_ratio) {
       result->w = dst.h * src_ratio;
       result->h = dst.h;
-      result->x = dst.x + (dst.w - result->w) / 2;
-      result->y = dst.y;
+      result->x = (dst.w - result->w) / 2;
+      result->y = 0;
     } else {
-      result->x = dst.x;
-      result->y = dst.y;
+      result->x = 0;
+      result->y = 0;
       result->w = dst.w;
       result->h = dst.h;
     }
@@ -163,7 +147,7 @@ gst_video_sink_class_init (GstVideoSinkClass * klass)
   /**
    * GstVideoSink:show-preroll-frame:
    *
-   * Whether to show video frames during preroll. If set to %FALSE, video
+   * Whether to show video frames during preroll. If set to #FALSE, video
    * frames will only be rendered in PLAYING state.
    */
   g_object_class_install_property (gobject_class, PROP_SHOW_PREROLL_FRAME,
@@ -179,6 +163,12 @@ gst_video_sink_class_init (GstVideoSinkClass * klass)
   g_type_class_add_private (klass, sizeof (GstVideoSinkPrivate));
 }
 
+static void
+gst_video_sink_base_init (gpointer g_class)
+{
+  GST_DEBUG_CATEGORY_INIT (video_sink_debug, "videosink", 0, "GstVideoSink");
+}
+
 static GstFlowReturn
 gst_video_sink_show_preroll_frame (GstBaseSink * bsink, GstBuffer * buf)
 {
@@ -267,3 +257,30 @@ gst_video_sink_get_property (GObject * object, guint prop_id,
       break;
   }
 }
+
+/* Public methods */
+
+GType
+gst_video_sink_get_type (void)
+{
+  static GType videosink_type = 0;
+
+  if (!videosink_type) {
+    static const GTypeInfo videosink_info = {
+      sizeof (GstVideoSinkClass),
+      gst_video_sink_base_init,
+      NULL,
+      (GClassInitFunc) gst_video_sink_class_init,
+      NULL,
+      NULL,
+      sizeof (GstVideoSink),
+      0,
+      (GInstanceInitFunc) gst_video_sink_init,
+    };
+
+    videosink_type = g_type_register_static (GST_TYPE_BASE_SINK,
+        "GstVideoSink", &videosink_info, 0);
+  }
+
+  return videosink_type;
+}
