@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifndef __GST_AUDIO_RATE_H__
@@ -25,8 +25,19 @@
 
 G_BEGIN_DECLS
 
-#define GST_TYPE_AUDIO_RATE (gst_audio_rate_get_type())
-G_DECLARE_FINAL_TYPE (GstAudioRate, gst_audio_rate, GST, AUDIO_RATE, GstElement)
+#define GST_TYPE_AUDIO_RATE \
+  (gst_audio_rate_get_type())
+#define GST_AUDIO_RATE(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_AUDIO_RATE,GstAudioRate))
+#define GST_AUDIO_RATE_CLASS(klass) \
+  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_AUDIO_RATE,GstAudioRate))
+#define GST_IS_AUDIO_RATE(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_AUDIO_RATE))
+#define GST_IS_AUDIO_RATE_CLASS(klass) \
+  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_AUDIO_RATE))
+
+typedef struct _GstAudioRate GstAudioRate;
+typedef struct _GstAudioRateClass GstAudioRateClass;
 
 /**
  * GstAudioRate:
@@ -54,12 +65,19 @@ struct _GstAudioRate
 
   gboolean discont;
 
+  gboolean new_segment;
   /* we accept all formats on the sink */
   GstSegment sink_segment;
   /* we output TIME format on the src */
   GstSegment src_segment;
 };
-GST_ELEMENT_REGISTER_DECLARE (audiorate);
+
+struct _GstAudioRateClass
+{
+  GstElementClass parent_class;
+};
+
+GType gst_audio_rate_get_type (void);
 
 G_END_DECLS
 
